version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/pia-data.log", replace

// PIA 3-FIRM DATA 1990, 1992-1998

use cellid currno year lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed kappa1 mu labfbl labfwh apimmo1x frms_obs using "brazaux/pia/random-3firm-rndmnr", clear
foreach var in lnoutput lnapk1 lnapq1 lnlabfbl lnlabfwh lnintmed labfbl labfwh apimmo1x {
  replace `var' = `var' / frms_obs
  label var `var' "(mean) `var'"
  }
merge cellid currno using "brazaux/pia/random-3firm-firmlist-rndmnr"
tab _m  // _m==2: cells with less than three firms excluded from 3firm-firmlist
drop if _m==2
drop cellid currno indsp contyrs _m
order firm year
sort firm year

* settings for productivity estimates (as in brazprod/%stata/%4tfp/prodlevel.do)
local esttype "op" /* "op" : Olley-Pakes */
local choice 3 /* Choice 3: FGV-IPA (and general) Deflators 86-98 */
if `choice'==3  local ext "ipa"
local fdfl 2 /* Choice 2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
global out 2 /* Choice 2: "output" */
if $out==2  local outtype "output"
global trd 0 /* Choice 0: trend variables and year dummies OFF */
if $trd==0  local trdtype "notrend"
global fe 1 /* Choice 1: fixed effects in OP estimation ON  */
if $fe  local fetype "fe"
global iniols 2 /* Choice 2: Set initial values to FE estimates and terms from linear regression */
global polynl 3 /* Choice 3: Polynomial of 3rd order is used in Step 3 */
local polynl=$polynl
global xeff 1 /* Choice 1: Approximate for X-efficiency choice by managers */
if $xeff  local xeff="x"

* derive productivity figures at Nivel 50
sort niv50
merge niv50 using "brazaux/pia/prodcoeff-brazprod", nokeep
tab _m
qui count if _m~=3
if `r(N)' > 0  STOP
if "`esttype'" == "op" {
  if $fe~=2 {
   if $out==2 {
    if $trd==3  gen lntfp = lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed - bklegri*kletgril
    else        gen lntfp = lnoutput - betak*lnapk1 - betaq*lnapq1 - betabl*lnlabfbl - betawh*lnlabfwh - betaintm*lnintmed
    }
  }
}
label var lntfp "Log TFP"
if "`esttype'" == "op" {
    if $out==2  gen double lnlp=lntfp + betak*lnapk1 + betaq*lnapq1 - (1-betabl-betawh)*log((exp(lnlabfwh)+exp(lnlabfbl))) + betaintm*lnintmed
  }
label var lnlp "Log LP"
if "`esttype'" == "op"  gen double bgkap = betakappa * kappa1
label var bgkap "betak * gk * kappa"
if "`esttype'" == "op"  gen double bgmu = betamu * mu
label var bgmu "betam * gm * mu"

gen ln_empl = ln(labfbl + labfwh)
label var ln_empl "Log Employment"
gen ln_cap = ln(apimmo1x)
label var ln_cap "Log Capital"
gen ln_cap_empl = ln_cap - ln_empl
label var ln_cap_empl "Log of Capital / Labor Force"

* finalize
keep firm year lntfp lnlp ln_cap_empl
foreach var in lntfp lnlp ln_cap_empl {
  rename `var' firm_`var'
  }
sort firm year
save "brazrloc/data/pia-data", replace

log close
