version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/secex90-subsibge-expval.log", replace

* mapping cnpj_radic to subs_ibge
foreach file in a b c d e f g h i j {
  tempfile subs`file'
  use cnpj_radic ano mod_subs_ibge if ano==1990 using "rais/base-agg/cnpjradic/aggcnpj_`file'.dta", clear
  rename mod_subs_ibge subs_ibge
  drop ano
  save `subs`file''
  }
use `subsa'
foreach file in b c d e f g h i j {
  append using `subs`file''
  }
tempfile subsibge
sort cnpj_radic
save `subsibge'

* country mapping
tempfile cntrymap
use "brazaux/conc/countries/country-table.dta", clear
keep secexkey wtfkey
duplicates drop
sort secexkey wtfkey
save `cntrymap'

* sector-country weights from SECEX 1990
insheet using "secex/csv/exp90.csv", clear
keep cgc pais valor
order cgc pais valor
rename cgc cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename pais secexkey
label var secexkey "Three-digit SECEX code"
rename valor expvalue
label var expvalue "Export value"
sort secexkey
joinby secexkey using `cntrymap', unmatched(both) _merge(_merge)
tab _merge
drop if wtfkey==.
drop secexkey _merge
duplicates drop
sort cnpj_radic
merge cnpj_radic using `subsibge', nokeep
tab _m

collapse (sum) expvalue, by(subs_ibge wtfkey)
egen _exptot = sum(expvalue), by(subs_ibge)
gen expweight = expvalue/_exptot
drop _exptot
label var expvalue "Export value"
label var expweight "Export weight (by subs_ibge)"

order wtfkey subs_ibge
sort wtfkey subs_ibge
save "brazrloc/auxil/subsibge-country-exp90", replace

log close
