version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/wtf-data-by-sitc4.log", replace

local regdef "APD CEE LAC NAM ODV OIN WEU"

* mapping SITC4 to subsibge
tempfile sec2subs
use "brazaux/conc/sec/sitc2subsibge.dta", clear
drop sitc4dgt
rename sitc2 sitc4
sort sitc4
compress
save `sec2subs'

* mapping wtf to regiao
tempfile regiao
use wtfkey regiao using "brazaux/conc/countries/country-table.dta", clear
duplicates drop
drop if wtfkey==.
rename wtfkey _wtfkey
gen str6 wtfkey=string(_wtfkey)
drop _wtfkey
sort wtfkey
save `regiao'

* year loop
forvalues yr = 86/100 {

tempfile wtf`yr'
local loadyr = `yr'
if `yr'==100 local loadyr 00

* annual country-sector-level data
use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf`loadyr'.dta", clear
rename value value`yr'
collapse (sum) value`yr', by(icode importer sitc4) fast
rename icode wtfkey
drop if wtfkey=="100000" | wtfkey=="999990"  // world or intl organizations

* country-sector-level aggregates
sort wtfkey
joinby using `regiao', unmatched(both) _merge(_merge)
drop if wtfkey=="481561"  // not in importer list wtf-list.csv; wtfname = "China FTZ" (see brazaux/%stata/%0ext-prep/country-conc.do)
qui count if _m==1
if `r(N)'>0  STOP  // unmatched wtf country codes
tab _m
drop if _m==2
drop _m
list wtfkey if regiao==""
compress

* region-level (Brazilian export-weighted) aggregates, by sector and year
drop if wtfkey=="330760"   // drop Brazil
gen long _wtfkey = int(real(wtfkey))
drop wtfkey
rename _wtfkey wtfkey
sort sitc4
joinby sitc4 using `sec2subs', _merge(_merge) unmatched(both)
* qui count if _m==1
* if `r(N)'>0  STOP  // unmatched sitc4 industry codes
tab _m
drop if _m==2
collapse (sum) value`yr', by(subs_ibge regiao) fast
reshape long value, i(subs_ibge regiao) j(year)
replace year = year + 1900
label var year "Calendar year"
rename value imp
label var imp "Regional imports (excl. Brazil)"
rename imp imp_
reshape wide imp_, i(subs_ibge year) j(regiao) string
foreach reg in `regdef' {
  label var imp_`reg' "Non-Brazil Imports in `reg'"
  }
compress
sort subs_ibge year
save `wtf`yr'', replace

} // close year loop

use `wtf86', clear
forvalues yr = 87/100 {
  append using `wtf`yr''
  }
drop if subs_ibge==. | year==.

sort subs_ibge year
save "brazrloc/auxil/wtf-data-by-sitc4.dta", replace

log close
