version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/tfp"

capture log close
log using "brazrloc/logs/tfp-stats.log", replace

// Haltiwanger
* note: term3 is covariance-like term (raw moment, not subtracting mean)
use "braztfp/decomp/haltiwanger-op-ipa2-output-notrend-fe-3x", clear
gen tfp_term23 = tfp_term2 + tfp_term3
gen lp_term23 = lp_term2 + lp_term3
drop tfp_term2 tfp_term3 lp_term2 lp_term3
order year dlntfp tfp_term1 tfp_term23 tfp_term4 tfp_term5 dlnlp lp_term1 lp_term23 lp_term4 lp_term5
rename year _rowname
qui save haltiw_tbl.dta
qui matload haltiw_tbl, dropall over missing(.)
qui erase haltiw_tbl.dta
matorder haltiw_tbl, m(haltiw_tfp_tbl) ifc(dlntfp tfp_term1 tfp_term23 tfp_term4 tfp_term5)
est2tex haltiw_tfp, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3)
matorder haltiw_tbl, m(haltiw_lp_tbl) ifc(dlnlp lp_term1 lp_term23 lp_term4 lp_term5)
est2tex haltiw_lp, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3)
matorder haltiw_tbl, m(haltiw_all_tbl) ifc(dlntfp tfp_term1 tfp_term23 tfp_term4 tfp_term5 dlnlp lp_term1 lp_term23 lp_term4 lp_term5)
est2tex haltiw_all, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3) extracols(5)
mat drop haltiw_tbl haltiw_tfp_tbl haltiw_lp_tbl haltiw_all_tbl

// Alternative Haltiwanger
use "braztfp/decomp/haltiwanger-op-ipa2-output-notrend-fe-3x", clear
gen tfp_term12 = tfp_term1 + tfp_term2
gen lp_term12 = lp_term1 + lp_term2
drop tfp_term1 tfp_term2 lp_term1 lp_term2
order year dlntfp tfp_term12 tfp_term3 tfp_term4 tfp_term5 dlnlp lp_term12 lp_term3 lp_term4 lp_term5
rename year _rowname
qui save haltiw_tbl.dta
qui matload haltiw_tbl, dropall over missing(.)
qui erase haltiw_tbl.dta
matorder haltiw_tbl, m(haltiw_tfp_tbl) ifc(dlntfp tfp_term12 tfp_term3 tfp_term4 tfp_term5)
matorder haltiw_tbl, m(haltiw_lp_tbl) ifc(dlnlp lp_term12 lp_term3 lp_term4 lp_term5)
matorder haltiw_tbl, m(haltiw_alt_tbl) ifc(dlntfp tfp_term12 tfp_term3 tfp_term4 tfp_term5 dlnlp lp_term12 lp_term3 lp_term4 lp_term5)
est2tex haltiw_alt, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3) extracols(5)
mat drop haltiw_tbl haltiw_tfp_tbl haltiw_lp_tbl
* mat drop haltiw_alt_tbl

// Olley-Pakes
use "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x", clear
order year agglntfp unwlntfp covtfp agglnlp unwlnlp covlp
rename year _rowname
qui save ollpak_tbl.dta
qui matload ollpak_tbl, dropall over missing(.)
qui erase ollpak_tbl.dta
est2tex ollpak, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3) extracols(3)
mat drop ollpak_tbl

// Olley-Pakes rebased to 1990 and mixed with alternative Haltiwanger
use "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x-1990", clear
order year agglntfp unwlntfp covtfp agglnlp unwlnlp covlp
rename year _rowname
qui save ollpak_alt_tbl.dta
qui matload ollpak_alt_tbl, dropall over missing(.)
qui erase ollpak_alt_tbl.dta
local ollpaklbl : colfullnames ollpak_alt_tbl
local haltiwlbl : colfullnames haltiw_alt_tbl
mat ollpak_alt_tbl = ollpak_alt_tbl , ( J(1,10,.) \ haltiw_alt_tbl )
matrix colnames ollpak_alt_tbl = `ollpaklbl' `haltiwlbl'
mat drop haltiw_alt_tbl
matorder ollpak_alt_tbl, m(ollpak_alt_tbl) over ifc(agglntfp unwlntfp covtfp tfp_term3 agglnlp unwlnlp covlp lp_term3)
est2tex ollpak_alt, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3) extracols(4)

// Olley-Pakes rebased to 1990 and mixed with correlation coefficients of annual changes
use "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x-1990", clear
order year agglntfp unwlntfp covtfp agglnlp unwlnlp covlp
rename year _rowname
qui save ollpak_aerrr_tbl.dta
qui matload ollpak_aerrr_tbl, dropall over missing(.)
qui erase ollpak_aerrr_tbl.dta
local ollpaklbl : colfullnames ollpak_aerrr_tbl
use "braztfp/tex/rhotab_op_tbl", clear
gen _period = _rowname
replace _period = "1990/86" if _rowname=="1987/86" | _rowname=="1988/87" | _rowname=="1989/88" | _rowname=="1990/89"
replace _period = "1994/92" if _rowname=="1993/92" | _rowname=="1994/93"
replace _period = "1998/95" if _rowname=="1995/94" | _rowname=="1996/95" | _rowname=="1997/96" | _rowname=="1998/97"
drop _rowname
rename _period _rowname
foreach var of varlist dtheta_dftfp dlambda_dflnlp dfsize_dlbftot {
  egen _`var'=mean(`var'), by(_rowname)
  drop `var'
  rename _`var' `var'
  }
qui save rhotab_op_tbl.dta
qui matload rhotab_op_tbl, dropall over missing(.)
qui erase rhotab_op_tbl.dta
local rhotablbl : colfullnames rhotab_op_tbl
mat ollpak_aerrr_tbl = ollpak_aerrr_tbl , ( J(1,3,.) \ rhotab_op_tbl )
matrix colnames ollpak_aerrr_tbl = `ollpaklbl' `rhotablbl'
mat drop rhotab_op_tbl
matorder ollpak_aerrr_tbl, m(ollpak_aerrr_tbl) over ifc(agglntfp unwlntfp covtfp dtheta_dftfp agglnlp unwlnlp covlp dlambda_dflnlp dfsize_dlbftot)
est2tex ollpak_aerrr, replace dropall preserve ready p(brazrloc/tex/v4/tfp) fancy digits(3) extracols(4 8)

log close
