version 8.2
clear
set logtype text
set more off
set matsize 200
tempfile pia

capture mkdir "brazrloc/tex/v4"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime/laborstats"
capture mkdir "brazrloc/tex/v4/metromale-prime"
capture mkdir "brazrloc/tex/v4/metromale-prime/laborstats"

capture log close
log using "brazrloc/logs/katz-murphy.log", replace

// PRIME-AGE MALES NATIONWIDE and METROPOLITAN, SUBSECTOR IBGE DATA 

foreach sample in "natl-maleprime" "metromale-prime" {

foreach sector in "" "trad" "nont" {

if "`sample'"=="natl-maleprime" {
  use wid ano identificad subs_ibge occagg rem_media grau_instr sexo fx_etaria using "brazrloc/data/wid-draw-workers-natl", clear
  drop if sexo==2  // drop female workers
  drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
  drop sexo fx_etaria
  sort wid ano
  }
if "`sample'"=="metromale-prime" {
  use wid ano identificad subs_ibge occagg rem_media grau_instr sexo fx_etaria using "brazrloc/data/wid-draw-workers-metro-male", clear
  drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
  }

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* generate five education levels
gen byte edulvl = 1 if grau_instr==1 | grau_instr==2
replace  edulvl = 2 if grau_instr==3 | grau_instr==4
replace  edulvl = 3 if grau_instr==5 | grau_instr==6
replace  edulvl = 4 if grau_instr==7 | grau_instr==8
replace  edulvl = 5 if grau_instr==9
label define edulvl 1 "Illiterate or Primary School Dropout" 2 "Primary School Graduate or Middle School Dropout" 3 "Middle School Graduate or High School Dropout" 4 "High School Graduate or College Dropout" 5 "College Graduate", add
label values edulvl edulvl
label var edulvl "Schooling"
drop grau_instr

* transform to efficiency units, summing to unity by year
collapse (sum) rem_media, by(ano subs_ibge occagg edulvl) fast
sort ano subs_ibge occagg edulvl
drop if subs_ibge==. | occagg==. | edulvl==.
fillin ano subs_ibge occagg edulvl
summ _fillin
rename rem_media effunits                             // E_jkt
label var effunits "Efficienty units"
replace effunits = 0 if _fillin
drop _fillin
egen double _et  = sum(effunits), by(ano)             // E_t
gen double stdeffunits = (effunits/_et)               // E_jkt
label var stdeffunits "Stand'zd efficiency units [1]"
drop _et

* save for loop
tempfile forloop
save `forloop'

foreach timespan in "1986 1990" "1990 1997" "1997 2001" "1990 1998" "1986 2001" {

tokenize `timespan'
local year0 = `1'
local year1 = `2'
local yr0 = substr("`1'",-2,2)
local yr1 = substr("`2'",-2,2)

* sector-occupation shifts in relative employment
foreach jgroup in "subs occ" "subs" {
local name = subinstr("`jgroup'"," ","",.)
use `forloop', clear
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (sum) stdeffunits, by(ano `jgroup' edulvl) fast
egen double _ej  = sum(stdeffunits), by(`jgroup')          // E_j
egen double _ejk = sum(stdeffunits), by(`jgroup' edulvl)   // E_jk
gen double ajk = _ejk/_ej                                  // \alpha_jk = E_jk / E_j
egen double _e   = sum(stdeffunits)
egen double _ek  = sum(stdeffunits), by(edulvl)
gen double ek    = _ek/_e                                  // E_k
egen double _ejt = sum(stdeffunits), by(`jgroup' ano)      // E_jt
keep if ano==`year0' | ano==`year1'
sort `jgroup' edulvl ano
gen double delej = _ejt - _ejt[_n-1] if ano==`year1'       // \Delta E_j
drop if ano==`year0'
drop _ejt ano
gen double _delxj = (ajk/ek)*delej                         // (\alpha_jk * \Delta E_j)/E_k
egen double delx`name'`yr0'`yr1' = sum(_delxj), by(edulvl) // \sum_j (\alpha_jk * \Delta E_j)/E_k
label var delx`name'`yr0'`yr1' "Between sector-occupation change"
sort edulvl `jgroup'
// create delx`name'`yr0'`yr1' matrix
keep edulvl delx
duplicates drop
decode edulvl, gen(_rowname)
drop edulvl
replace _rowname = trim(lower(substr(_rowname,1,5)))
compress
order _rowname delx`name'`yr0'`yr1'
save "brazrloc/tex/v4/`sample'/laborstats/katzmurp`yr0'`yr1'`sector'_tbl.dta", replace
matload katzmurp`yr0'`yr1'`sector'_tbl, p(brazrloc/tex/v4/`sample'/laborstats) over dropall
mat rename katzmurp`yr0'`yr1'`sector'_tbl delx`name'`yr0'`yr1'
}  // close `jgroup' loop

* shifts in relative employment
use `forloop', clear
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (sum) effunits, by(ano edulvl) fast
egen double ek   = sum(effunits), by(edulvl)           // E_k
egen double _ekt = sum(effunits), by(edulvl ano)       // E_kt
keep if ano==`year0' | ano==`year1'
sort edulvl ano
gen double delek = _ekt - _ekt[_n-1] if ano==`year1'   // \Delta E_k
drop if ano==`year0'
drop _ekt ano
gen double delxtot`yr0'`yr1' = (1/ek)*delek            // \Delta E_k/E_k
label var delxtot`yr0'`yr1' "Overall education"
sort edulvl
// create delxtot`yr0'`yr1' matrix
keep edulvl delxtot
duplicates drop
decode edulvl, gen(_rowname)
drop edulvl
replace _rowname = trim(lower(substr(_rowname,1,5)))
compress
order _rowname delxtot`yr0'`yr1'
save "brazrloc/tex/v4/`sample'/laborstats/katzmurp`yr0'`yr1'`sector'_tbl.dta", replace
matload katzmurp`yr0'`yr1'`sector'_tbl, p(brazrloc/tex/v4/`sample'/laborstats) over dropall
mat rename katzmurp`yr0'`yr1'`sector'_tbl delxtot`yr0'`yr1'

* final matrix
mat delwsubsocc`yr0'`yr1' = delxtot`yr0'`yr1' - delxsubsocc`yr0'`yr1'
matrix colnames delwsubsocc`yr0'`yr1' = delwsubsocc`yr0'`yr1'
mat delwsubs`yr0'`yr1' = delxtot`yr0'`yr1' - delxsubs`yr0'`yr1'
matrix colnames delwsubs`yr0'`yr1' = delwsubs`yr0'`yr1'
mat katzmurp`yr0'`yr1'`sector'_tbl = delxsubs`yr0'`yr1' , delwsubs`yr0'`yr1' , delxsubsocc`yr0'`yr1' , delwsubsocc`yr0'`yr1' , delxtot`yr0'`yr1'
est2tex katzmurp`yr0'`yr1'`sector', ready p(brazrloc/tex/v4/`sample'/laborstats) replace fancy dropall
mat drop katzmurp`yr0'`yr1'`sector'_tbl delxsubs`yr0'`yr1' delwsubs`yr0'`yr1' delxsubsocc`yr0'`yr1' delwsubsocc`yr0'`yr1' delxtot`yr0'`yr1'

}  // close `timespan' loop

}  // close `sector' loop

}  // close `sample' loop

log close
