version 8.2
clear
set logtype text
set more off
set matsize 300

capture mkdir "brazrloc/math/"
capture mkdir "brazrloc/math/v4/"
capture mkdir "brazrloc/math/v4/natl"
capture mkdir "brazrloc/math/v4/natl-maleprime"
capture mkdir "brazrloc/math/v4/metromale"
capture mkdir "brazrloc/math/v4/metromale-prime"
capture mkdir "brazrloc/math/v4pmeadj/"
capture mkdir "brazrloc/math/v4pmeadj/natl"
capture mkdir "brazrloc/math/v4pmeadj/natl-maleprime"
capture mkdir "brazrloc/math/v4pmeadj/metromale"
capture mkdir "brazrloc/math/v4pmeadj/metromale-prime"

capture log close
log using "brazrloc/logs/transitions-eigvec.log", replace


// PME statistics to assess nonF-nonF transition (entry [7,7] in transition matrix), PRIME-AGE MALES

use "brazrloc/pme/pme-revision.dta", clear
tab year
tab t48
label list ccdd

mat pme_nonF_nonF = J(1,12,.)
mat rownames pme_nonF_nonF = nonF
mat colnames pme_nonF_nonF = nonF nonF_4yr nonF_8690 nonF_9094 nonF_9498 nonF_9098 nonF_86_90 nonF_90_94 nonF_94_98 nonF_90_91 nonF_96_97 nonF_vr4yr

preserve
foreach mat in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr" {
  restore, preserve
  local yrdif "2yr"
  if substr("`mat'",2,3)=="4yr" | substr("`mat'",4,5)=="4yr"  local yrdif "4yr"
  if substr("`mat'",4,2)=="_9" {
    local strtyr = substr("`mat'",2,2)
    local endyr = substr("`mat'",5,2)
    keep if year>=`strtyr' & year<=`endyr'
    if `endyr'-`strtyr'==4  local yrdif "4yr"
    }
  if substr("`mat'",4,1)=="9" {
    local strtyr = substr("`mat'",2,2)
    local endyr = substr("`mat'",4,2)
    keep if year>=`strtyr' & year<=`endyr'
    if `endyr'-`strtyr'==4  local yrdif "4yr"
    }
  * transition matrix:  F   nonF
  *                 F   a   1-a   where a: `Fend'/`Fini'
  *              nonF  1-b   b          b: `nonFend'/`nonFini'
  * 4-year B: b^3 + (1-b)(1-a)b + b(1-b)(1-a) + ba(1-a)
  qui count if ( t48>=7 & t48<=12 ) | ( t48>=13 & t48<=18 ) | ( t48>=19 & t48<=24 ) | ( t48>=25 & t48<=30 )
  local nonFini = `r(N)'
  qui count if ( t48>=8 & t48<=12 ) | ( t48>=14 & t48<=18 ) | ( t48>=20 & t48<=24 ) | ( t48>=26 & t48<=30 )
  local nonFend = `r(N)'
  qui count if ( t48>=1 & t48<=6 )
  local Fini = `r(N)'
  qui count if ( t48==1 )
  local Fend = `r(N)'
  if "`yrdif'"=="2yr"  mat pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")] = `nonFend'/`nonFini'
  if "`yrdif'"=="4yr"  mat pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")] = (`nonFend'/`nonFini')^3 + 2*(`nonFend'/`nonFini')*(1-`nonFend'/`nonFini')*(1-`Fend'/`Fini') + (`nonFend'/`nonFini')*(1-`Fend'/`Fini')*(`Fend'/`Fini')
  } // close `mat' loop
restore
mat list pme_nonF_nonF


// stata2math, PRIME-AGE MALES

foreach sampl in "metromale-prime" "natl-maleprime" {
foreach mat in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr" {
* disp in ye "`mat'"

use "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac`mat'_tbl.dta", clear
drop if _row=="Total"
drop _row total
qui count
if `r(N)'~=7  STOP  // more than 7 rows
if n_a[7]~=0  STOP  // non-zero failure entry

outsheet using "brazrloc/math/v4/`sampl'/xts`mat'.tab", nonames replace

* replace nonF-nonF transition with PME estimate
replace n_a = pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")]*100 in 7
foreach var in cadv1st cadv2nd cadv3rd cadv4th cadv5th nontrad {
  replace `var' = `var' * (1 - pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")]) in 7
  }
egen _chk = rsum(cadv1st cadv2nd cadv3rd cadv4th cadv5th nontrad n_a)
qui summ _chk
if float(`r(mean)')~=float(100)  STOP
drop _chk

outsheet using "brazrloc/math/v4pmeadj/`sampl'/xts`mat'.tab", nonames replace

} // close `sampl' loop
} // close `mat' loop


// PME statistics to assess nonF-nonF transition (entry [7,7] in transition matrix), ALL WORKERS

use "brazrloc/pme/t48-year.dta", clear
tab year
tab t48
label list ccdd

mat pme_nonF_nonF = J(1,12,.)
mat rownames pme_nonF_nonF = nonF
mat colnames pme_nonF_nonF = nonF nonF_4yr nonF_8690 nonF_9094 nonF_9498 nonF_9098 nonF_86_90 nonF_90_94 nonF_94_98 nonF_90_91 nonF_96_97 nonF_vr4yr

preserve
foreach mat in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr" {
  restore, preserve
  local yrdif "2yr"
  if substr("`mat'",2,3)=="4yr"  local yrdif "4yr"
  if substr("`mat'",4,2)=="_9" {
    local strtyr = substr("`mat'",2,2)
    local endyr = substr("`mat'",5,2)
    keep if year>=`strtyr' & year<=`endyr'
    if `endyr'-`strtyr'==4  local yrdif "4yr"
    }
  if substr("`mat'",4,1)=="9" {
    local strtyr = substr("`mat'",2,2)
    local endyr = substr("`mat'",4,2)
    keep if year>=`strtyr' & year<=`endyr'
    if `endyr'-`strtyr'==4  local yrdif "4yr"
    }
  * transition matrix:  F   nonF
  *                 F   a   1-a   where a: `Fend'/`Fini'
  *              nonF  1-b   b          b: `nonFend'/`nonFini'
  * 4-year B: b^3 + (1-b)(1-a)b + b(1-b)(1-a) + ba(1-a)
  qui count if ( t48>=7 & t48<=12 ) | ( t48>=13 & t48<=18 ) | ( t48>=19 & t48<=24 ) | ( t48>=25 & t48<=30 )
  local nonFini = `r(N)'
  qui count if ( t48>=8 & t48<=12 ) | ( t48>=14 & t48<=18 ) | ( t48>=20 & t48<=24 ) | ( t48>=26 & t48<=30 )
  local nonFend = `r(N)'
  qui count if ( t48>=1 & t48<=6 )
  local Fini = `r(N)'
  qui count if ( t48==1 )
  local Fend = `r(N)'
  if "`yrdif'"=="2yr"  mat pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")] = `nonFend'/`nonFini'
  if "`yrdif'"=="4yr"  mat pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")] = (`nonFend'/`nonFini')^3 + 2*(`nonFend'/`nonFini')*(1-`nonFend'/`nonFini')*(1-`Fend'/`Fini') + (`nonFend'/`nonFini')*(1-`Fend'/`Fini')*(`Fend'/`Fini')
  } // close `mat' loop
restore
mat list pme_nonF_nonF


// stata2math, ALL WORKERS

local sampl "natl"
foreach mat in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr" {

use "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac`mat'_tbl.dta", clear
drop if _row=="Total"
drop _row total
qui count
if `r(N)'~=7  STOP  // more than 7 rows

outsheet using "brazrloc/math/v4/`sampl'/xts`mat'.tab", nonames replace

* replace nonF-nonF transition with PME estimate
replace n_a = pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")]*100 in 7
foreach var in cadv1st cadv2nd cadv3rd cadv4th cadv5th nontrad {
  replace `var' = `var' * (1 - pme_nonF_nonF[1,colnumb(pme_nonF_nonF,"nonF`mat'")]) in 7
  }
egen _chk = rsum(cadv1st cadv2nd cadv3rd cadv4th cadv5th nontrad n_a)
qui summ _chk
if float(`r(mean)')~=float(100)  STOP
drop _chk

outsheet using "brazrloc/math/v4pmeadj/`sampl'/xts`mat'.tab", nonames replace

} // close `mat' loop


// math2tex, PRIME-AGE MALES and ALL WORKERS; Geweke&al (1986) mobility index

disp in red "Process matrices in Mathmatica"
disp in red "Then press more to proceed"
set more on
more
set more off

foreach sampl in "metromale-prime" "natl-maleprime" "natl" {

mat xts_tradsec_unac_mobidx_tbl = J(12,1,.)
mat rownames xts_tradsec_unac_mobidx_tbl = _all _4yr _8690 _9094 _9498 _9098 _86_90 _90_94 _94_98 _90_91 _96_97 _vr4yr
mat colnames xts_tradsec_unac_mobidx_tbl = one_abs(det(xts))

foreach mat in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr" {

matload xts_tradsec_unac`mat'_tbl, p(brazrloc/tex/v4/`sampl'/trans) over dropall missing(.)
local rows = rowsof(xts_tradsec_unac`mat'_tbl)
local cols = colsof(xts_tradsec_unac`mat'_tbl)
if `rows'~=`cols'  STOP  // not a square matrix
local colnames "cadv1st cadv2nd cadv3rd cadv4th cadv5th nontrad n_a"

infile `colnames' using "brazrloc/math/v4/`sampl'/xts`mat'_eigvec.dat", clear
mkmat *, mat(xts`mat'_tbl)
matrix rownames xts`mat'_tbl = stat_unadj
mat eigvecle = xts`mat'_tbl * J(7,1,1)
local eigvecle = eigvecle[1,1]
mat xts`mat'_tbl = (xts`mat'_tbl/`eigvecle') * 100
est2tex xts`mat', ready p(brazrloc/math/v4/`sampl') replace fancy digits(1) dropall
mat xts`mat'_unadj = xts`mat'_tbl , J(1,1,100)

infile `colnames' using "brazrloc/math/v4pmeadj/`sampl'/xts`mat'_eigvec.dat", clear
mkmat *, mat(xts`mat'_tbl)
matrix rownames xts`mat'_tbl = stat_pmeadj
mat eigvecle = xts`mat'_tbl * J(7,1,1)
local eigvecle = eigvecle[1,1]
mat xts`mat'_tbl = (xts`mat'_tbl/`eigvecle') * 100
est2tex xts`mat', ready p(brazrloc/math/v4pmeadj/`sampl') replace fancy digits(1) dropall
mat xts`mat'_adj = xts`mat'_tbl , J(1,1,100)

mat xts_tradsec_unac`mat'_eigv_tbl = xts_tradsec_unac`mat'_tbl \ xts`mat'_unadj \ xts`mat'_adj
est2tex xts_tradsec_unac`mat'_eigv, ready p(brazrloc/tex/v4/`sampl'/trans) replace fancy digits(1) dropall

insheet using "brazrloc/math/v4pmeadj/`sampl'/xts`mat'.tab", nonames clear
mkmat *, matrix(xts`mat')
mat xts`mat' = xts`mat'/100
mat xts_tradsec_unac_mobidx_tbl[rownumb(xts_tradsec_unac_mobidx_tbl,"`mat'"),1] = 1 - abs(det(xts`mat'))

} // close `mat' loop

est2tex xts_tradsec_unac_mobidx, ready p(brazrloc/tex/v4/`sampl'/trans) replace fancy digits(7) dropall

} // close `sampl' loop

log close
