version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/reaccessions-aer-natl-rr.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm subs_balcadv firm_indexp"  // cut: subs_reffpen, added: subs_balcadv
local secexog  ""  // cut: subs_balcadv
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local addlreg  "subs_indprown_pis occ_indoutsrc"
local basdsply "subs_tarfoutp_dsplyr subs_tarfintm_dsplyr firm_indexp_dsplyr"  // cut: subs_reffpen_dsplyr
local secdsply "subs_balcadv_dsplyr"


* reaccessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

// rehired worker sample

tempfile rehrsmpl
use wid year year_rehir rehircat mo2rehir subs_tarfoutp subs_tarfintm subs_balcadv firm_indexp subs_reffpen indsubs* using "brazrloc/data/hazard-durations-natl-subsibge.dta", clear
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* merge tradable sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  drop indsubs_`i'
  }
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
drop balarank aggsec subs_ibge

* reset displacement year variables
foreach var in year tradsec subs_tarfoutp subs_tarfintm subs_balcadv firm_indexp subs_reffpen {
  rename `var' `var'_dsplyr
  }
rename year_rehir year
order wid year
sort wid year
save `rehrsmpl'

// accessions sample

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m subs_ibge
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  }

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"

* displacement sector and worker information for rehires
sort wid year
merge wid year using `rehrsmpl', nokeep
tab _m

* rehiring indicator (disregard hires without recorded displacement in past 4 years)
gen byte indrhir = indhire
replace indrhir = . if indhire==1 & _merge~=3
drop _merge


* clogit reaccession regressions

clogit indrhir `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990 & indrhir~=., group(wid) robust iterate(`maxiter')
est2vec subsrhir_aerrr, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_reffpen subs_secrealx subs_fdiflw subs_herfsale  plant_lnempl plant_indcoll plant_indhigh plant_indwhittot tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv  subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv  subs_tarfoutp_notindprim subs_tarfintm_notindprim  subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite  subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_nofe)
est2vec subsrhir_aerrr, r(F p df df_r) name(clogit_nofe)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit indrhir `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990 & indrhir~=., group(wid) robust iterate(`maxiter')
est2vec subsrhir_aerrr, addto(subsrhir_aerrr) name(clogit_secyrfe)
est2vec subsrhir_aerrr, raddto(subsrhir_aerrr) name(clogit_secyrfe)

clogit indrhir `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990 & indrhir~=., group(wid) robust iterate(`maxiter')
est2vec subsrhir_aerrr, addto(subsrhir_aerrr) name(clogit_secyrfe0)
est2vec subsrhir_aerrr, raddto(subsrhir_aerrr) name(clogit_secyrfe0)

foreach tsec in 1 2 3 4 5 7 {
clogit indrhir `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990 & indrhir~=. & (tradsec_dsplyr==`tsec' |  tradsec_dsplyr==.), group(wid) robust iterate(`maxiter')
est2vec subsrhir_aerrr, addto(subsrhir_aerrr) name(clogit_secyrfe_tsec`tsec')
est2vec subsrhir_aerrr, raddto(subsrhir_aerrr) name(clogit_secyrfe_tsec`tsec')

clogit indrhir `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990 & indrhir~=. & (tradsec_dsplyr==`tsec' |  tradsec_dsplyr==.), group(wid) robust iterate(`maxiter')
est2vec subsrhir_aerrr, addto(subsrhir_aerrr) name(clogit_secyrfe_tsec`tsec'0)
est2vec subsrhir_aerrr, raddto(subsrhir_aerrr) name(clogit_secyrfe_tsec`tsec'0)
}


* duration regressions: reaccession-year regressors

xtreg mo2rehir `basendog' `secexog' `basdsply' `secdsply' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_reffpen subs_secrealx subs_fdiflw subs_herfsale  plant_lnempl plant_indcoll plant_indhigh plant_indwhittot tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv  subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv  subs_tarfoutp_notindprim subs_tarfintm_notindprim  subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite  subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(xt_yrfe)
est2vec subsm2rhr_ryr_aerrr, r(F p df df_r) name(xt_yrfe)

xtreg mo2rehir `basendog' `secexog' `basdsply' `secdsply' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, addto(subsm2rhr_ryr_aerrr) name(xt_secyrfe)
est2vec subsm2rhr_ryr_aerrr, raddto(subsm2rhr_ryr_aerrr) name(xt_secyrfe)

xtreg mo2rehir `basendog' `basdsply' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, addto(subsm2rhr_ryr_aerrr) name(xt_secyrfe0)
est2vec subsm2rhr_ryr_aerrr, raddto(subsm2rhr_ryr_aerrr) name(xt_secyrfe0)

xtreg mo2rehir `basendog' `secexog' `basdsply' `secdsply' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, addto(subsm2rhr_ryr_aerrr) name(xt_secyrtrdfe)
est2vec subsm2rhr_ryr_aerrr, raddto(subsm2rhr_ryr_aerrr) name(xt_secyrtrdfe)

xtreg mo2rehir `basendog' `basdsply' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, addto(subsm2rhr_ryr_aerrr) name(xt_secyrtrdfe0)
est2vec subsm2rhr_ryr_aerrr, raddto(subsm2rhr_ryr_aerrr) name(xt_secyrtrdfe0)

xtivreg mo2rehir `secexog' `secdsply' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' `basdsply' = `ivlst') if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, addto(subsm2rhr_ryr_aerrr) name(xtiv_secyrfe)
est2vec subsm2rhr_ryr_aerrr, raddto(subsm2rhr_ryr_aerrr) name(xtiv_secyrfe)

xtivreg mo2rehir `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' `basdsply' = `ivlst') if year>=1990, fe i(wid)
est2vec subsm2rhr_ryr_aerrr, addto(subsm2rhr_ryr_aerrr) name(xtiv_secyrfe0)
est2vec subsm2rhr_ryr_aerrr, raddto(subsm2rhr_ryr_aerrr) name(xtiv_secyrfe0)


* duration regressions: displacement-year regressors

use "brazrloc/data/hazard-durations-natl-subsibge.dta", clear

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  }

xtreg mo2rehir `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_reffpen subs_secrealx subs_fdiflw subs_herfsale  plant_lnempl plant_indcoll plant_indhigh plant_indwhittot tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv  subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv  subs_tarfoutp_notindprim subs_tarfintm_notindprim  subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite  subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(xt_yrfe)
est2vec subsm2rhr_aerrr, r(F p df df_r) name(xt_yrfe)

xtreg mo2rehir `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, addto(subsm2rhr_aerrr) name(xt_secyrfe)
est2vec subsm2rhr_aerrr, raddto(subsm2rhr_aerrr) name(xt_secyrfe)

xtreg mo2rehir `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, addto(subsm2rhr_aerrr) name(xt_secyrfe0)
est2vec subsm2rhr_aerrr, raddto(subsm2rhr_aerrr) name(xt_secyrfe0)

xtreg mo2rehir `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, addto(subsm2rhr_aerrr) name(xt_secyrtrdfe)
est2vec subsm2rhr_aerrr, raddto(subsm2rhr_aerrr) name(xt_secyrtrdfe)

xtreg mo2rehir `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, addto(subsm2rhr_aerrr) name(xt_secyrtrdfe0)
est2vec subsm2rhr_aerrr, raddto(subsm2rhr_aerrr) name(xt_secyrtrdfe0)

xtivreg mo2rehir `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, addto(subsm2rhr_aerrr) name(xtiv_secyrfe)
est2vec subsm2rhr_aerrr, raddto(subsm2rhr_aerrr) name(xtiv_secyrfe)

xtivreg mo2rehir `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsm2rhr_aerrr, addto(subsm2rhr_aerrr) name(xtiv_secyrfe0)
est2vec subsm2rhr_aerrr, raddto(subsm2rhr_aerrr) name(xtiv_secyrfe0)


// Save results

foreach type in b se e r {
  matsave subsrhir_aerrr_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave subsm2rhr_ryr_aerrr_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave subsm2rhr_aerrr_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }

log close
