version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/separations-accessions-aer-natl-rr-intract-cluster.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract2_90  "subs_tarfoutp_balcadv_90 subs_tarfintm_balcadv_90"
local intract2_90a "subs_tarfoutp_volrcadv_90 subs_tarfintm_volrcadv_90"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract3_90  "subs_tarfoutp_indexp_balcadv_90 subs_tarfintm_indexp_balcadv_90"
local intract3_90a "subs_tarfoutp_indexp_volrcadv_90 subs_tarfintm_indexp_volrcadv_90"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local intract7 "subs_tarfoutp_indfemal subs_tarfintm_indfemal"  // if indfemal
local intract8 "subs_tarfoutp_notindprim subs_tarfintm_notindprim firm_indexp_notindprim subs_balcadv_notindprim"
local intract9 "subs_tarfoutp_indexp_notindprim subs_tarfoutp_balcadv_notindprim subs_tarfintm_indexp_notindprim subs_tarfintm_balcadv_notindprim"
local addlreg  "subs_indprown_pis occ_indoutsrc"


* SEPARATIONS NATL

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* reference year 1998
drop indyr_13

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"

* regressions

xtreg inddspl `basendog' `secexog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) robust cluster(subs_ibge)
* est2vec subsdspl_berman_intract, addto(subsdspl_berman_intract) name(xt_intract2)
* est2vec subsdspl_berman_intract, raddto(subsdspl_berman_intract) name(xt_intract2)

xtreg inddspl `basendog' `secexog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) robust cluster(subs_ibge)
* est2vec subsdspl_berman_intract, addto(subsdspl_berman_intract) name(xt_intract3)
* est2vec subsdspl_berman_intract, raddto(subsdspl_berman_intract) name(xt_intract3)


* ACCESSIONS NATL

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }
gen byte subs_ibge = .
label var subs_ibge "Subsector IBGE"
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* reference year 1998
drop indyr_13

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"

* regressions

xtreg indhire `basendog' `secexog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) robust cluster(subs_ibge)
* est2vec subshire_berman_intract, addto(subshire_berman_intract) name(xt_intract2)
* est2vec subshire_berman_intract, raddto(subshire_berman_intract) name(xt_intract2)

xtreg indhire `basendog' `secexog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid) robust cluster(subs_ibge)
* est2vec subshire_berman_intract, addto(subshire_berman_intract) name(xt_intract3)
* est2vec subshire_berman_intract, raddto(subshire_berman_intract) name(xt_intract3)


log close
