version 8.2
clear
set more off
set mem 800m
set matsize 800

capture mkdir "brazrloc/tex/v4/reg"
capture mkdir "brazrloc/tex/v4/natl/reg"

capture log close
log using "brazrloc/logs/fe-corr.log", replace

// RAIS SUBSECTOR IBGE

* Load variable names and save for est2tex
est2extlbl, addto(ureg) intex($root/brazrloc/%stata/rowlbl-brazrloc) p(brazrloc/tex/v4/natl/reg) replace
est2extlbl, addto(yreff) retain p(brazrloc/tex/v4/natl/reg) replace
est2extlbl, addto(fecorr) retain p(brazrloc/tex/v4/natl/reg) replace
clear


// CORRELATIONS WITH WORKER-FIXED EFFECTS

* separations (merging in accessions)
use wid year subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv indexcl if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl
sort wid
merge wid using "brazrloc/estmat/v4/reg/natl/subsdspl_u.dta"
tab _m
drop if _m~=3
drop _m
corr2tex u_dspl subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv, p(brazrloc/tex/v4/natl/reg) name(udspl) fancy replace
reg u_dspl subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv
est2vec ureg, vars(u_dspl subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv __brl_d population _ibx50d) e(N r2) name(udspl)
sort wid
merge wid using "brazrloc/estmat/v4/reg/natl/subshire_u.dta"
tab _m
drop if _m~=3
drop _m
corr2tex u_dspl u_hire subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv, p(brazrloc/tex/v4/natl/reg) name(udsplhire) fancy replace
reg u_hire u_dspl subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv
est2vec ureg, addto(ureg) name(uhiredspl)

* accessions (merging in separations)
use wid year subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv indexcl if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl
sort wid
merge wid using "brazrloc/estmat/v4/reg/natl/subshire_u.dta"
tab _m
drop if _m~=3
drop _m
corr2tex u_hire subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv, p(brazrloc/tex/v4/natl/reg) name(uhire) fancy replace
reg u_hire subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv
est2vec ureg, addto(ureg) name(uhire)

est2tex ureg, replace p(brazrloc/tex/v4/natl/reg) fancy digits(3) dropall level(90 95 99) mark(starse)


// CORRELATIONS WITH YEAR-FIXED EFFECTS

foreach margin in dspl hire {
  matload subs`margin'_aerrr_b, p(brazrloc/estmat/v4/reg/natl) over missing(.) dropall
  matorder subs`margin'_aerrr_b, m(subs`margin'_aerrr_b) ifc(clogit_secyrfe0) over
  matorder subs`margin'_aerrr_b, m(subs`margin'_aerrr_b) ifr(indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12) over
  }

tempfile auxdat
insheet using "brazrloc/auxil/origs/pib.csv", clear
keep ano populacao pib_corrente_usd
rename ano year
label var year "Calendar Year"
rename populacao population
label var population "Population [mio]"
rename pib_corrente_usd gdp_usd
replace gdp_usd = gdp_usd/1000000
label var gdp_usd "GDP [current USD bio]"
keep if year>=1986 & year<=1998
sort year
merge year using "brazrloc/auxil/globfin-annual", nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
sort year
save `auxdat'

* separations
use wid year subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_secrealx subs_fdiflw subs_herfsale indexcl if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl
keep if year>=1990 & year<=1998
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
gen yreffdspl = .
label var yreffdspl "Year-fixed Effect"
local i 4
forvalues year = 1990/1997 {
  local i = `i' + 1
  replace yreffdspl = subsdspl_aerrr_b[rownumb(subsdspl_aerrr_b,"indyr_`i'"),colnumb(subsdspl_aerrr_b,"clogit_secyrfe0")] if year==`year'
  }
order wid year yreffdspl
sort wid year

preserve
  collapse (mean) yreffdspl subs_tarfoutp subs_tarfintm subs_balcadv subs_fdiflw subs_herfsale firm_indexp subs_secrealx population gdp_usd __brl_d cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym, by(year) fast
  reg yreffdspl subs_tarfoutp subs_tarfintm
  reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d
  foreach var in population gdp_usd cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym {
    qui reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d `var'
    test `var'
    }
  reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d population
  foreach var in gdp_usd cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym {
    qui reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d population `var'
    test `var'
    }
restore

reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d population
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In separation sample"
est2vec yreff, vars(u_dspl subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv __brl_d population _ibx50d) e(N r2) name(dspl_poptarf)
reg yreffdspl __brl_d population if indsmpl
est2vec yreff, addto(yreff) name(dspl_pop)
reg yreffdspl subs_tarfoutp subs_tarfintm if indsmpl
est2vec yreff, addto(yreff) name(dspl_poptarfonly)
drop indsmpl

reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d _ibx50d
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In separation sample"
est2vec yreff, addto(yreff) name(dspl_ibxtarf)
reg yreffdspl __brl_d _ibx50d if indsmpl
est2vec yreff, addto(yreff) name(dspl_ibx)
reg yreffdspl subs_tarfoutp subs_tarfintm if indsmpl
est2vec yreff, addto(yreff) name(dspl_ibxtarfonly)
drop indsmpl

reg yreffdspl subs_tarfoutp subs_tarfintm __brl_d population _ibx50d
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In separation sample"
est2vec yreff, addto(yreff) name(dspl_popibxtarf)
reg yreffdspl __brl_d population _ibx50d if indsmpl
est2vec yreff, addto(yreff) name(dspl_popibx)
reg yreffdspl subs_tarfoutp subs_tarfintm if indsmpl
est2vec yreff, addto(yreff) name(dspl_popibxtarfonly)
drop indsmpl

* accessions
use wid year subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_secrealx subs_fdiflw subs_herfsale indexcl if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl
keep if year>=1990 & year<=1998
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
gen yreffhire = .
label var yreffhire "Year-fixed Effect"
local i 4
forvalues year = 1990/1997 {
  local i = `i' + 1
  replace yreffhire = subshire_aerrr_b[rownumb(subshire_aerrr_b,"indyr_`i'"),colnumb(subshire_aerrr_b,"clogit_secyrfe0")] if year==`year'
  }
order wid year yreffhire
sort wid year

preserve
  collapse (mean) yreffhire subs_tarfoutp subs_tarfintm subs_balcadv subs_fdiflw subs_herfsale firm_indexp subs_secrealx population gdp_usd __brl_d cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym, by(year) fast
  reg yreffhire subs_tarfoutp subs_tarfintm
  reg yreffhire subs_tarfoutp subs_tarfintm __brl_d
  foreach var in population gdp_usd cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym {
    qui reg yreffhire subs_tarfoutp subs_tarfintm __brl_d `var'
    test `var'
    }
  reg yreffhire subs_tarfoutp subs_tarfintm __brl_d population
  foreach var in gdp_usd cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym {
    qui reg yreffhire subs_tarfoutp subs_tarfintm __brl_d population `var'
    test `var'
    }
restore

reg yreffhire subs_tarfoutp subs_tarfintm __brl_d population
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In separation sample"
est2vec yreff, addto(yreff) name(hire_poptarf)
reg yreffhire __brl_d population if indsmpl
est2vec yreff, addto(yreff) name(hire_pop)
reg yreffhire subs_tarfoutp subs_tarfintm if indsmpl
est2vec yreff, addto(yreff) name(hire_poptarfonly)
drop indsmpl

reg yreffhire subs_tarfoutp subs_tarfintm __brl_d _ibx50d
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In separation sample"
est2vec yreff, addto(yreff) name(hire_ibxtarf)
reg yreffhire __brl_d _ibx50d if indsmpl
est2vec yreff, addto(yreff) name(hire_ibx)
reg yreffhire subs_tarfoutp subs_tarfintm if indsmpl
est2vec yreff, addto(yreff) name(hire_ibxtarfonly)
drop indsmpl

reg yreffhire subs_tarfoutp subs_tarfintm __brl_d population _ibx50d
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In separation sample"
est2vec yreff, addto(yreff) name(hire_popibxtarf)
reg yreffhire __brl_d population _ibx50d if indsmpl
est2vec yreff, addto(yreff) name(hire_popibx)
reg yreffhire subs_tarfoutp subs_tarfintm if indsmpl
est2vec yreff, addto(yreff) name(hire_popibxtarfonly)
drop indsmpl

est2tex yreff, replace p(brazrloc/tex/v4/natl/reg) fancy digits(3) dropall level(90 95 99) mark(starse)


// SINGLE FE-CORR TABLE

matload ureg_tbl, p(brazrloc/tex/v4/natl/reg) over dropall missing(.)
matorder ureg_tbl, m(ureg_tbl) over ifc(udspl uhire uhiredspl)
matload yreff_tbl, p(brazrloc/tex/v4/natl/reg) over dropall missing(.)
matorder yreff_tbl, m(yreff_tbl) over ifc(dspl_popibxtarf hire_popibxtarf)
mat fecorr_tbl = ureg_tbl , yreff_tbl
mat drop ureg_tbl yreff_tbl
est2tex fecorr, ready replace p(brazrloc/tex/v4/natl/reg) fancy digits(3) dropall extracols(3) level(90 95 99) mark(starse)

log close
