version 8.2
clear
set more off
set matsize 800

capture mkdir "brazrloc/tex/v4/natl10pct"
capture mkdir "brazrloc/tex/v4/natl10pct/reg"

capture log close
log using "brazrloc/logs/simulation.log", replace

* SEPARATIONS
use if ~indexcl using "brazrloc/data/separations-natl-subsibge-10pct.dta", clear
* merge additional sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb
* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep  // CNAE sector information in 1994-2001
foreach var in secrealx fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  replace cnae_`var' = subs_`var' if year<=1993  // keep subsibge information for 1986-1993
  drop subs_`var'
  }
gen long cnaemix = cnae // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if year<=1993  // keep subsibge information for 1986-1993
drop _m
tabstat inddspl cnae_tarfoutp cnae_tarfintm, by(year) stats(mean) save
mat dspl = r(StatTot)
mat rownames dspl = total
mat coleq dspl = dspl
local i 0
forvalues yr = 86/98 {
  local i = `i'+1
  mat dspl = dspl \ r(Stat`i')
  local lstrow = rowsof(dspl)
  matname dspl 19`yr', rows(`lstrow') explicit 
  }

* ACCESSIONS
use if ~indexcl using "brazrloc/data/accessions-natl-subsibge-10pct.dta", clear
* merge additional sector information
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb
* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta", keep(mod_clas_cnae_95) nokeep
drop _m
rename ano year
rename mod_clas_cnae_95 cnae
replace cnae=. if cnae==-1 | cnae==0
replace cnae=int(cnae/10)
sort cnae year
merge cnae year using "brazrloc/auxil/sector-cnae-data.dta", nokeep  // CNAE sector information in 1994-2001
foreach var in secrealx fdiflw reffpen tarfoutp tarfintm herfsale indprown_pis indprown_pis_95 dollar ppieu ppinam {
  replace cnae_`var' = subs_`var' if year<=1993  // keep subsibge information for 1986-1993
  drop subs_`var'
  }
gen long cnaemix = cnae // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if year<=1993  // keep subsibge information for 1986-1993
drop _m
tabstat indhire cnae_tarfoutp cnae_tarfintm, by(year) stats(mean) save
mat hire = r(StatTot)
mat rownames hire = total
mat coleq hire = hire
local i 0
forvalues yr = 86/98 {
  local i = `i'+1
  mat hire = hire \ r(Stat`i')
  local lstrow = rowsof(hire)
  matname hire 19`yr', rows(`lstrow') explicit 
  }

* SIMULATION MATRIX
mat simul = dspl , hire
matsave simul, p(brazrloc/tex/v4/natl10pct/reg) t(double) replace dropall

log close
